﻿
/* IMPORT CUSTOM LIBRARIES */
import gs.TweenMax;
import fl.motion.easing.*;




var fontHelvetica:Font = new Helvetica();
var letterString = [];

init();




function init()
{
	var bg = new Shape();
	bg.name = "bg";
	bg.graphics.beginFill(0x000000);
	bg.graphics.drawRect(0, 0, stage.stageWidth, stage.stageHeight);
	bg.graphics.endFill();
	stage.addChild(bg);
	
	var format:TextFormat = new TextFormat();
	format.font = fontHelvetica.fontName;
	format.size = 28;
	format.bold = true;
	format.color = 0xFFFFFF;
	
	var logo = new TextField();
	logo.name = "logo";
	logo.embedFonts = true;
	logo.defaultTextFormat = format;
	logo.autoSize = "left";
	logo.text = "Bokeh Type";
	logo.x = 15;
	logo.y = 15;
	stage.addChild(logo);
	
	var format:TextFormat = new TextFormat();
	format.font = fontHelvetica.fontName;
	format.size = 16;
	format.color = 0xFFFFFF;
	
	var intro = new TextField();
	intro.name = "intro";
	intro.embedFonts = true;
	intro.defaultTextFormat = format;
	intro.autoSize = "left";
	intro.text = "Click here and type";
	intro.x = stage.stageWidth / 2 - intro.width / 2;
	intro.y = stage.stageHeight / 2 - intro.height / 2;
	stage.addChild(intro);

	var INTRO_CIRCLE_RADIUS = intro.width / (13/8);	
	var introCircle = new Shape();
	introCircle.name = "introCircle";
	introCircle.graphics.beginFill(0x333333);
	introCircle.graphics.lineStyle(4, 0x666666);
	introCircle.graphics.drawCircle(0, 0, INTRO_CIRCLE_RADIUS);
	introCircle.graphics.endFill();
	introCircle.x = stage.stageWidth / 2;
	introCircle.y = stage.stageHeight / 2;
	stage.addChild(introCircle);
	
	var introBlur = new TextField();
	introBlur.name = "introBlur";
	introBlur.embedFonts = true;
	introBlur.defaultTextFormat = format;
	introBlur.autoSize = "left";
	introBlur.text = intro.text;
	introBlur.x = stage.stageWidth / 2 - introBlur.width / 2;
	introBlur.y = stage.stageHeight / 2 - introBlur.height / 2;
	stage.addChild(introBlur);

	var blur:BlurFilter = new BlurFilter();
	blur.blurX = 4;
	blur.blurY = 4;
	introBlur.filters = [blur];

	var introBlurMask = new Shape();
	introBlurMask.name = "introBlurMask";
	introBlurMask.graphics.beginFill(0xFFFFFF, 0.15);
	introBlurMask.graphics.lineStyle(4, 0xFFFFFF, 0.5);
	introBlurMask.graphics.drawCircle(0, 0, INTRO_CIRCLE_RADIUS);
	introBlurMask.graphics.endFill();
	introBlurMask.x = stage.stageWidth / 2;
	introBlurMask.y = stage.stageHeight / 2;
	introBlur.mask = introBlurMask;
	
	circleShrink();
	
	function circleGrow()
	{
		TweenMax.to(
			introCircle,
			2,
			{
				scaleX: 1,
				scaleY: 1,
				onComplete: circleShrink
			}
		);	

		TweenMax.to(
			introBlurMask,
			2,
			{
				scaleX: 1,
				scaleY: 1
			}
		);	
	}
	
	function circleShrink()
	{
		TweenMax.to(
			introCircle,
			2,
			{
				scaleX: 0.3,
				scaleY: 0.3,
				onComplete: circleGrow
			}
		);	

		TweenMax.to(
			introBlurMask,
			2,
			{
				scaleX: 0.5,
				scaleY: 0.5
			}
		);	
	}
	
	stage.addEventListener(KeyboardEvent.KEY_DOWN, function(event)
		{
			if (letterString.length < 6 && event.charCode >= 33 && event.charCode <= 126)
			{
				drawLetter(String.fromCharCode(event.charCode));
			}
		}
	);
	
	stage.addEventListener(Event.RESIZE, function(event){stageResize()});
	stage.addEventListener(MouseEvent.CLICK, clickStage);
	
	stageResize();
}




function clickStage(event)
{
	var intro = stage.getChildByName("intro");
	
	TweenMax.killTweensOf(intro);
	TweenMax.to(
		intro,
		0.5,
		{
			alpha: 0
		}
	);
	
	var introBlur = stage.getChildByName("introBlur");

	TweenMax.killTweensOf(introBlur);
	TweenMax.to(
		introBlur,
		0.5,
		{
			alpha: 0
		}
	);

	var introCircle = stage.getChildByName("introCircle");

	TweenMax.killTweensOf(introCircle);
	TweenMax.to(
		introCircle,
		0.5,
		{
			alpha: 0,
			onComplete: function()
			{
				introCircle.parent.removeChild(introCircle);
			}
		}
	);

	stage.removeEventListener(MouseEvent.CLICK, clickStage);
}




function stageResize()
{
	var bg = stage.getChildByName("bg");
	bg.width = stage.stageWidth;
	bg.height = stage.stageHeight;
}




function drawLetter(character)
{
	var letters = stage.getChildByName("letters");
	
	if (letters == null)
	{
		letters = new Sprite();
		letters.name = "letters";
		stage.addChild(letters);
	}
	
	var letterFormat:TextFormat = new TextFormat();
	letterFormat.font = fontHelvetica.fontName;
	letterFormat.size = 128;
	letterFormat.bold = true;
	letterFormat.color = 0xFFFFFF;
	
	var letter = new TextField();
	letter.name = "letter";
	letter.embedFonts = true;
	letter.defaultTextFormat = letterFormat;
	letter.autoSize = "left";
	letter.text = character;
	
	var tempLettersString = "";
	
	for (var i = 0; i < letterString.length; i++)
	{
		tempLettersString += letterString[i].character;
	}
	
	var tempLetters = new TextField();
	tempLetters.embedFonts = true;
	tempLetters.defaultTextFormat = letterFormat;
	tempLetters.autoSize = "left";
	tempLetters.text = tempLettersString;
	
	var MULTIPLICATION = Math.min(3, stage.stageHeight / (11 / 4) / 128);
	var lettersWidth = tempLetters.width * MULTIPLICATION;

	for (var i = 0; i < letterString.length; i++)
	{
		var tempLetters = new TextField();
		tempLetters.embedFonts = true;
		tempLetters.defaultTextFormat = letterFormat;
		tempLetters.autoSize = "left";
		tempLetters.text = tempLettersString.substring(0, i);
	
		TweenMax.to(
			letterString[i].dots,
			1,
			{
				x: stage.stageWidth / 2 - (lettersWidth + letter.width * MULTIPLICATION) / 2 + tempLetters.width * MULTIPLICATION
			}
		);
	}
		
	var bitmapData = new BitmapData(letter.width, letter.height, true, 0x00000000);
	bitmapData.draw(letter);

	var dots = new Sprite();
	dots.name = "dots";
	dots.x = stage.stageWidth / 2 - (lettersWidth + letter.width * MULTIPLICATION) / 2 + lettersWidth;
	dots.y = stage.stageHeight / 2 - letter.height * MULTIPLICATION / 2;
	dots.scaleX = MULTIPLICATION;
	dots.scaleY = MULTIPLICATION;
	letters.addChild(dots);

	letterString.push({character: character, dots: dots});

	var seedColor = (Math.random() * 225 + 30) << 16 | (Math.random() * 225 + 30) << 8 | (Math.random() * 225 + 30);
	
	for (var i = 0; i < 60;)
	{
		var point = new Point(Math.round(Math.random() * bitmapData.width), Math.round(Math.random() * bitmapData.height));
		
		if (bitmapData.hitTest(new Point(), 0xFF, point))
		{
			var POINT_DEVIANCE = 0;
			point.x += 2 * -POINT_DEVIANCE * Math.random() + POINT_DEVIANCE;
			point.y += 2 * -POINT_DEVIANCE * Math.random() + POINT_DEVIANCE;
			
			var dot = new Shape();
			dot.name = "dot";
			dot.alpha = 0;
			dot.x = point.x;
			dot.y = point.y;
			
			var MIN_SCALE = 0;
			var MAX_ALPHA = 1;
			var MAX_RADIUS = 13;
			
			if (Math.random() < 0.05)
			{
				MAX_RADIUS = 60;
				MAX_ALPHA = 0.2;
			}
			
			var MIN_RADIUS = 4;
			var radius = Math.random() * MAX_RADIUS + MIN_RADIUS;
			var seedR = seedColor >> 16 & 0xff;
			var seedG = seedColor >> 8 & 0xff;
			var seedB = seedColor & 0xff;
			
			var COLOR_DEVIANCE = 80;
			seedR += 2 * -COLOR_DEVIANCE * Math.random() + COLOR_DEVIANCE;
			seedR = Math.max(Math.min(seedR, 255), 0);
			seedG += 2 * -COLOR_DEVIANCE * Math.random() + COLOR_DEVIANCE;
			seedG = Math.max(Math.min(seedG, 255), 0);
			seedB += 2 * -COLOR_DEVIANCE * Math.random() + COLOR_DEVIANCE;
			seedB = Math.max(Math.min(seedB, 255), 0);
			var color = seedR << 16 | seedG << 8 | seedB;
			
			dot.graphics.beginFill(color, ((MAX_RADIUS + MIN_RADIUS) - radius) / MAX_RADIUS);
			dot.graphics.drawCircle(0, 0, radius);
			i++;

			var FADE_LENGTH = 6;
			var MAX_DELAY = 1.2;
			
			TweenMax.to(
				dot,
				FADE_LENGTH,
				{
					delay: Math.random() * MAX_DELAY,
					scaleX: MIN_SCALE,
					scaleY: MIN_SCALE,
					alpha: 0,
					blurFilter:
					{
						blurX: radius / 2,
						blurY: radius / 2
					},
					bezier:
					[
						{alpha: MAX_ALPHA}
					],
					onStart: function(dot)
					{
						dots.addChild(dot);
					},
					onStartParams: [dot],
					onComplete: function(dot)
					{
						dot.parent.removeChild(dot);
						
						if (dots.numChildren == 0)
						{
							dots.parent.removeChild(dots);
						}
					},
					onCompleteParams: [dot]
				}
			);
		}
	}

	var timer:Timer = new Timer(3000, 1);
	timer.addEventListener(TimerEvent.TIMER, function()
		{
			letterString.shift();
		}
	);
	timer.start();
}